function plotProps = func_initPlotPropsStruct(typeStr)
% Author: Lloyd Fletcher
% PhotoDyn Group, University of Southampton
% Date: 19/2/2018

    if nargin == 0
        typeStr = 'other';
    end
    
    plotProps.screenSize = get(groot,'Screensize');
    plotProps.interpText = 'latex';
    plotProps.units = 'centimeters';
    plotProps.ratio = 1.618; 
    plotProps.pageSizeXcm = 18;
    plotProps.singleColFigFactor = 1.5;
    plotProps.imageSeqSaveRes = '-r300';
    plotProps.imageSeqFormat = '-dpng';
    plotProps.titleAlign = 'center';
    plotProps.black = [0.2,0.2,0.2];
    %,'color',plotProps.black
    
    % Creates a data struct for plot properties
    if strcmp(typeStr,'presentation')
        plotProps.format = '-dpng';       % File format for image saving
        plotProps.saveRes = '-r300';
       
        plotProps.locXcm = 0;            % Image location X
        plotProps.locYcm = 0;            % Image location Y 
        
        plotProps.sizePerFigXcm = 9;
        plotProps.sizePerFigYcm = plotProps.sizePerFigXcm/plotProps.ratio;
        
        plotProps.lw = 0.75;               % plot line width 
        plotProps.ms = 4.5;               % marker size for plots 
        
        plotProps.ft = 'arial';         % font for figures 
        plotProps.fs = 10;              % heading font sizez
        plotProps.hfs = 11;
        plotProps.lfs = 10;
        plotProps.txtFs = 8;
        
        plotProps.colormap = jet;
        
        plotProps.lLoc = 'eastoutside';
        
    elseif strcmp(typeStr,'article')
        plotProps.format = '-dpng';       % File format for image saving
        plotProps.saveRes = '-r300';
        
        plotProps.locXcm = 0;            % Image location in pixels 
        plotProps.locYcm = 0;            % Image location in pixels 

        plotProps.sizePerFigXcm = 9;
        plotProps.sizePerFigYcm = plotProps.sizePerFigXcm/plotProps.ratio;
        
        plotProps.lw = 0.6;             % plot line width 
        plotProps.ms = 4;               % marker size for plots 
        
        plotProps.ft = 'times';         % font for figures 
        plotProps.fs = 9;
        plotProps.hfs = 10;
        plotProps.lfs = 9;
        plotProps.txtFs = 8;
        
        plotProps.colormap = jet;
        
        plotProps.lLoc = 'eastoutside';
        
    elseif strcmp(typeStr,'article_v2')
        plotProps.format = '-dpng';       % File format for image saving
        plotProps.saveRes = '-r300';
        
        plotProps.locXcm = 0;            % Image location in pixels 
        plotProps.locYcm = 0;            % Image location in pixels 

        plotProps.sizePerFigXcm = 10;
        plotProps.sizePerFigYcm = plotProps.sizePerFigXcm/2;
        
        plotProps.lw = 0.5;             % plot line width 
        plotProps.ms = 4;               % marker size for plots 
        
        plotProps.ft = 'times';         % font for figures 
        plotProps.fs = 9;
        plotProps.hfs = 10;
        plotProps.lfs = 9;
        plotProps.txtFs = 8;
        
        plotProps.colormap = linspecer;
        
        plotProps.lLoc = 'eastoutside';
            
    else
        plotProps.format = '-dpng';       % File format for image saving
        plotProps.saveRes = '-r300';
       
        plotProps.locXcm = 0;            % Image location X
        plotProps.locYcm = 0;            % Image location Y 
        
        plotProps.sizePerFigXcm = 9;
        plotProps.sizePerFigYcm = plotProps.sizePerFigXcm/plotProps.ratio;
        
        plotProps.lw = 1;               % plot line width 
        plotProps.ms = 7;               % marker size for plots 
        
        plotProps.ft = 'arial';         % font for figures 
        plotProps.fs = 10;              % heading font sizez
        plotProps.hfs = 11;
        plotProps.txtFs = 8;
        
        plotProps.colormap = jet;
        
        plotProps.lLoc = 'northeast';
    end
    
    plotProps.lineStyleVec = {'-xb','-+r','-dk','-sg','-+b','-dr','-sk','-xg','-xb','-+r','-dk','-sg',};
    plotProps.lineStyleVec = [plotProps.lineStyleVec,plotProps.lineStyleVec,plotProps.lineStyleVec];
    plotProps.markerVec = {'ob','or','ok','og','ob','or','ok','og','ob','or','ok','og'};
    plotProps.letter = {'a','b','c','d','e','f','g','h','i','j','k','l','m','n'};
    plotProps.colour = {'b','r','g','k'};
    plotProps.marker = {'x','+','o','s','d','^'};
    plotProps.line = {'-','--','-.',':'};
    plotProps.singleLS = '-xb';
    plotProps.defColourMat = get(groot,'DefaultAxesColorOrder');
    
end

